@@ -6,13 +6,15 @@
 #include <string>
 
 class test : public Gtk_Window {
-    Gtk_VBox vbox;
-    Gtk_Button closebutton;
-    Gtk_HSeparator hsep;
+protected:
+  Gtk_EventBox ebox;
+  Gtk_VBox vbox;
+  Gtk_Button closebutton;
+  Gtk_HSeparator hsep;
 public:
-    test();
-    gint delete_event_impl(GdkEventAny*);
-    void add(Gtk_Widget *w) { vbox.pack_start(w,FALSE,FALSE,0); }
+  test();
+  gint delete_event_impl(GdkEventAny*);
+  void add(Gtk_Widget &w) { vbox.pack_start(w,FALSE,FALSE,0); }
 };
 
 class togglebuttontest : public test {
@@ -45,12 +47,17 @@ public:
 };
 
 #if GTK_MAJOR_VERSION > 1 || ( GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1)
-class itemfactorytest : public test {
-  Gtk_MenuBar *mb;
-  Gtk_ItemFactory *itemf;
+class ItemFactoryTest : public test {
 public:
-  itemfactorytest(void);
+  ItemFactoryTest(void);
   void itemcallback(string m);
+private:
+  gint buttonPress( GdkEventButton * event);
+  Gtk_ItemFactory *itemf;
+  //Gtk_MenuBar     *mb;
+  Gtk_ObjectHandle<Gtk_MenuBar> mb;
+  Gtk_ItemFactory              *popupFactory;
+  Gtk_ObjectHandle<Gtk_Menu>    popupMenu;
 };
 #endif
 
