@@ -12,12 +12,15 @@ class PipesTest : public Gtk_Window {
     Gtk_Text *text;
 public:
   PipesTest() 
-    : l("Hello World!"), b("Hello-button"), vb(new Gtk_VBox), text(new Gtk_Text)
+    : l("Hello World!"),
+      b("Hello-button"),
+      vb(new Gtk_VBox),
+      text(new Gtk_Text)
     {
 	add(vb);
-	vb->pack_start(&l);
-	vb->pack_start(&b);
-	vb->pack_start(text);
+	vb->pack_start(l);
+	vb->pack_start(b);
+	vb->pack_start(*text);
 	vb->show();
 	l.show();
 	b.show();
