@@ -1,3 +1,4 @@
+/* $Id: gnome--.h,v 1.10 1998/12/09 01:49:33 hp Exp $ */
 #ifndef GNOME_MINUS_MINUS_H
 #define GNOME_MINUS_MINUS_H 1
 
@@ -15,7 +16,7 @@ class Gnome_CanvasImage;
 class Gnome_CanvasLine;
 class Gnome_CanvasText;
 class Gnome_Canvas;
-class Gnome_ColorSelector;
+class Gnome_ColorPicker;
 class Gnome_Dialog;
 class Gnome_IconList;
 class Gnome_Main;
@@ -33,7 +34,7 @@ class Gnome_Pixmap;
 #include <gnome--/canvas-line.h>
 #include <gnome--/canvas-text.h>
 #include <gnome--/canvas.h>
-#include <gnome--/color-selector.h>
+#include <gnome--/color-picker.h>
 #include <gnome--/dialog.h>
 #include <gnome--/functions.h>
 #include <gnome--/icon-list.h>
